@@ -40,8 +40,8 @@ class TempDir(object):
                     tmpdir = Path(tempfile.gettempdir())
                 else:
                     tmpdir = Path(basedir)
-                tmpdir = tmpdir / '{}-of-{}'.format(prefix, os.environ['USER'])
-                print(tmpdir)
+                tmpdir = tmpdir / '{}-of-{}'.format(prefix, os.environ.get('USER', 'nobody'))
+                # print(tmpdir)
                 existing_dirs = {}
                 for x in tmpdir.glob(fmtstr.format('*')):
                     v = int(str(x).rsplit('-', 1)[1])
